@@ -52,4 +52,9 @@ def test_ymd():
     assert result.year == 2018
     assert result.month == 12
     assert result.day == 5
-    assert result.hour == 0
\ No newline at end of file
+    assert result.hour == 0
+
+
+def test_invalid_year():
+    with pytest.raises(ValueError):
+        fastdatetime.strptime("0-12-05", "%Y-%m-%d")
